@@ -1,12 +1,17 @@
+#![allow(dead_code)]
+
 use bevy::app::AppExit;
 use bevy::asset::AssetPlugin;
 use bevy::audio::AudioPlugin;
 use bevy::prelude::*;
 use bevy_asset_loader::{AssetCollection, AssetLoader};
 
-#[test]
+#[cfg_attr(all(not(feature = "2d"), not(feature = "3d")), test)]
 fn init_resource() {
-    let mut app = App::build();
+    let mut app = App::new();
+    app.add_plugins(MinimalPlugins)
+        .add_plugin(AssetPlugin::default())
+        .add_plugin(AudioPlugin::default());
 
     AssetLoader::new(MyStates::Load)
         .continue_to_state(MyStates::Next)
@@ -15,11 +20,8 @@ fn init_resource() {
         .build(&mut app);
 
     app.add_state(MyStates::Load)
-        .add_plugins(MinimalPlugins)
-        .add_plugin(AssetPlugin::default())
-        .add_plugin(AudioPlugin::default())
-        .add_system_set(SystemSet::on_update(MyStates::Load).with_system(timeout.system()))
-        .add_system_set(SystemSet::on_enter(MyStates::Next).with_system(expect.system()))
+        .add_system_set(SystemSet::on_update(MyStates::Load).with_system(timeout))
+        .add_system_set(SystemSet::on_enter(MyStates::Next).with_system(expect))
         .run();
 }
 
